..  Note: add links to github at each one

.. _inf_vs_ed:

Inferpy vs Edward
=======================

This section shows the equivalent Edward code for those models in `Probabilistic Model Zoo <probzoo.html>`_ section.



Bayesian Linear Regression
------------------------------------

.. literalinclude:: ../../examples/inf_vs_ed/linear_regression.py
   :language: python3
   :lines: 44-62



Gaussian Mixture
--------------------------

.. literalinclude:: ../../examples/inf_vs_ed/gaussian_mixture.py
   :language: python3
   :lines: 42-74



Logistic Regression
--------------------------

.. literalinclude:: ../../examples/inf_vs_ed/log_regression.py
   :language: python3
   :lines: 14-33




Multinomial Logistic Regression
--------------------------------------

.. literalinclude:: ../../examples/inf_vs_ed/multinomial_log_regression.py
   :language: python3
   :lines: 18-37


Linear Factor Model (PCA)
----------------------------------

.. literalinclude:: ../../examples/inf_vs_ed/pca.py
   :language: python3
   :lines: 13-30



PCA with ARD Prior (PCA)
--------------------------

.. literalinclude:: ../../examples/inf_vs_ed/pca_with_ARD_prior.py
   :language: python3
   :lines: 14-33


